@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: JRender.php 5336 2012-10-27 09:34:40Z fishbone $
+ * @version    SVN: $Id: JRender.php 5466 2012-12-13 05:26:01Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($this->gEnv->getJoomlaRootPath() . '/JParameter.php');
@@ -85,15 +85,17 @@ class JRender
 					$params->set('endLevel',		0);
 					$params->set('showAllChildren',	1);		// サブメニュー表示
 					$path = $gEnvManager->getTemplatesPath() . '/' . $templateId . '/html/mod_mainmenu/default.php';		// メニュー出力用スクリプト
-			
-					// ウィジェットが出力したメニューコンテンツを設定
-					$gEnvManager->setJoomlaMenuContent($content);
+					
+					if (file_exists($path)){
+						// ウィジェットが出力したメニューコンテンツを設定
+						$gEnvManager->setJoomlaMenuContent($content);
 
-					ob_clean();
-					require_once($gEnvManager->getJoomlaRootPath() . '/render/mainmenuHelper.php');		// デフォルトの出力方法
-					require($path);		// 毎回実行する
-					$content = ob_get_contents();
-					ob_clean();
+						ob_clean();
+						require_once($gEnvManager->getJoomlaRootPath() . '/render/mainmenuHelper.php');		// デフォルトの出力方法
+						require($path);		// 毎回実行する
+						$content = ob_get_contents();
+						ob_clean();
+					}
 				}
 			}
 		}
