@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainConfigsiteWidgetContainer.php 5111 2012-08-16 00:53:12Z fishbone $
+ * @version    SVN: $Id: admin_mainConfigsiteWidgetContainer.php 5128 2012-08-21 23:24:14Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainConfigbasicBaseWidgetContainer.php');
@@ -19,16 +19,18 @@ require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_mainDb.php');
 class admin_mainConfigsiteWidgetContainer extends admin_mainConfigbasicBaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	private $defaultLang;		// デフォルト言語
+	private $langId;		// 選択中の言語
 	private $permitMimeType;			// アップロードを許可する画像タイプ
+	private $isMultiLang;			// 多言語対応画面かどうか
 	
 	const TEST_MAIL_FORM = 'test';		// テストメールフォーム
-	const LICENSE_KEY		= 'license_key';		// ライセンスキー
+/*	const LICENSE_KEY		= 'license_key';		// ライセンスキー
 	const LICENSE_EMAIL		= 'license_email';		// ライセンスメール
 	const LICENSE_NAME = 'license_company_name';	// ライセンス会社名
 	const LICENSE_ZIPCODE	= 'license_company_zipcode';	// ライセンス郵便番号
 	const LICENSE_ADDRESS	= 'license_company_address';	// ライセンス住所
 	const LICENSE_FAX		= 'license_company_fax';	// ライセンスFAX
+	*/
 	const CF_SITE_LOGO_FILENAME = 'site_logo_filename';		// サイトロゴファイル
 	const SD_HEAD_OTHERS	= 'head_others';		// ヘッダその他タグ
 	
@@ -47,6 +49,8 @@ class admin_mainConfigsiteWidgetContainer extends admin_mainConfigbasicBaseWidge
 										image_type_to_mime_type(IMAGETYPE_JPEG),
 										image_type_to_mime_type(IMAGETYPE_PNG),
 										image_type_to_mime_type(IMAGETYPE_BMP));			// アップロードを許可する画像タイプ
+										
+		$this->isMultiLang = $this->gEnv->isMultiLanguageSite();			// 多言語対応画面かどうか
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -89,19 +93,25 @@ class admin_mainConfigsiteWidgetContainer extends admin_mainConfigbasicBaseWidge
 	{
 		// ユーザ情報、表示言語
 		$userInfo		= $this->gEnv->getCurrentUserInfo();
-		$this->defaultLang		= $this->gEnv->getDefaultLanguage();
-		$langId		= $this->gEnv->getCurrentLanguage();		// 現在の言語ID
+		$this->langId		= $this->gEnv->getDefaultLanguage();
+//		$langId		= $this->gEnv->getCurrentLanguage();		// 現在の言語ID
 		$siteLogoFiles = explode(';', $this->db->getSystemConfig(self::CF_SITE_LOGO_FILENAME));		// サイトロゴファイル名
 		
+		// 言語を取得
+		if ($this->isMultiLang){		// 多言語対応の場合
+			$langId = $request->trimValueOf('item_lang');				// 現在メニューで選択中の言語
+			if (!empty($langId)) $this->langId = $langId;
+		}
+		
 		$act = $request->trimValueOf('act');
 		if ($act == 'update'){		// 設定更新のとき
-			$licenseKey = $request->trimValueOf('license_key');		// ライセンスキー
+/*			$licenseKey = $request->trimValueOf('license_key');		// ライセンスキー
 			$licenseEmail = $request->trimValueOf('license_email');		// ライセンスメールアドレス
 			$licenseName = $request->trimValueOf('license_name');		// ライセンス会社名
 			$licenseZipcode = $request->trimValueOf('license_zipcode');		// ライセンス郵便番号
 			$licenseAddress = $request->trimValueOf('license_address');		// ライセンス住所
 			$licenseFax = $request->trimValueOf('license_fax');		// ライセンスFAX
-			//$siteOwner	= $request->trimValueOf('siteowner');		// サイト所有者
+			*/
 			$siteName	= $request->trimValueOf('sitename');		// サイト名称
 			$siteEmail	= trim($request->valueOf('siteemail'));		// サイトEメール
 			$siteCopyRight	= $request->trimValueOf('sitecopyright');		// サイト著作権
@@ -113,51 +123,45 @@ class admin_mainConfigsiteWidgetContainer extends admin_mainConfigbasicBaseWidge
 			$metaOthers		= $request->valueOf('meta_others');		// ヘッダその他タグ
 			
 			$isErr = false;
-			/*if (!$isErr && !empty($lang)){
-				if (!$this->db->updateSystemConfig(self::DEFAULT_LANG, $lang)) $isErr = true;
-			}*/
-			if (!$isErr){
-				if (!$this->db->updateSiteDef($this->defaultLang, self::LICENSE_KEY, $licenseKey)) $isErr = true;
+/*			if (!$isErr){
+				if (!$this->db->updateSiteDef($this->langId, self::LICENSE_KEY, $licenseKey)) $isErr = true;
 			}
 			if (!$isErr){
-				if (!$this->db->updateSiteDef($this->defaultLang, self::LICENSE_EMAIL, $licenseEmail)) $isErr = true;
+				if (!$this->db->updateSiteDef($this->langId, self::LICENSE_EMAIL, $licenseEmail)) $isErr = true;
 			}
 			if (!$isErr){
-				if (!$this->db->updateSiteDef($this->defaultLang, self::LICENSE_NAME, $licenseName)) $isErr = true;
+				if (!$this->db->updateSiteDef($this->langId, self::LICENSE_NAME, $licenseName)) $isErr = true;
 			}
 			if (!$isErr){
-				if (!$this->db->updateSiteDef($this->defaultLang, self::LICENSE_ZIPCODE, $licenseZipcode)) $isErr = true;
+				if (!$this->db->updateSiteDef($this->langId, self::LICENSE_ZIPCODE, $licenseZipcode)) $isErr = true;
 			}
 			if (!$isErr){
-				if (!$this->db->updateSiteDef($this->defaultLang, self::LICENSE_ADDRESS, $licenseAddress)) $isErr = true;
+				if (!$this->db->updateSiteDef($this->langId, self::LICENSE_ADDRESS, $licenseAddress)) $isErr = true;
 			}
 			if (!$isErr){
-				if (!$this->db->updateSiteDef($this->defaultLang, self::LICENSE_FAX, $licenseFax)) $isErr = true;
-			}			
-			/*
-			if (!$isErr){
-				if (!$this->db->updateSiteDef($this->defaultLang, M3_TB_FIELD_SITE_OWNER, $siteOwner)) $isErr = true;
-			}*/
+				if (!$this->db->updateSiteDef($this->langId, self::LICENSE_FAX, $licenseFax)) $isErr = true;
+			}
+			*/
 			if (!$isErr){		// サイト名
-				if (!$this->db->updateSiteDef($this->defaultLang, M3_TB_FIELD_SITE_NAME, $siteName)) $isErr = true;
+				if (!$this->db->updateSiteDef($this->langId, M3_TB_FIELD_SITE_NAME, $siteName)) $isErr = true;
 			}
 			if (!$isErr){
-				if (!$this->db->updateSiteDef($this->defaultLang, M3_TB_FIELD_SITE_EMAIL, $siteEmail)) $isErr = true;
+				if (!$this->db->updateSiteDef($this->langId, M3_TB_FIELD_SITE_EMAIL, $siteEmail)) $isErr = true;
 			}
 			if (!$isErr){		// 著作権
-				if (!$this->db->updateSiteDef($this->defaultLang, M3_TB_FIELD_SITE_COPYRIGHT, $siteCopyRight)) $isErr = true;
+				if (!$this->db->updateSiteDef($this->langId, M3_TB_FIELD_SITE_COPYRIGHT, $siteCopyRight)) $isErr = true;
 			}
 			if (!$isErr){
-				if (!$this->db->updateSiteDef($this->defaultLang, M3_TB_FIELD_SITE_TITLE, $siteTitle)) $isErr = true;
+				if (!$this->db->updateSiteDef($this->langId, M3_TB_FIELD_SITE_TITLE, $siteTitle)) $isErr = true;
 			}
 			if (!$isErr){
-				if (!$this->db->updateSiteDef($this->defaultLang, M3_TB_FIELD_SITE_DESCRIPTION, $siteDesc)) $isErr = true;
+				if (!$this->db->updateSiteDef($this->langId, M3_TB_FIELD_SITE_DESCRIPTION, $siteDesc)) $isErr = true;
 			}
 			if (!$isErr){
-				if (!$this->db->updateSiteDef($this->defaultLang, M3_TB_FIELD_SITE_KEYWORDS, $siteKeyword)) $isErr = true;
+				if (!$this->db->updateSiteDef($this->langId, M3_TB_FIELD_SITE_KEYWORDS, $siteKeyword)) $isErr = true;
 			}
 			if (!$isErr){
-				if (!$this->db->updateSiteDef($this->defaultLang, self::SD_HEAD_OTHERS, $metaOthers)) $isErr = true;
+				if (!$this->db->updateSiteDef($this->langId, self::SD_HEAD_OTHERS, $metaOthers)) $isErr = true;
 			}
 			if ($isErr){
 				$this->setMsg(self::MSG_APP_ERR, $this->_('Failed in updating data.'));			// データ更新に失敗しました
@@ -165,24 +169,25 @@ class admin_mainConfigsiteWidgetContainer extends admin_mainConfigbasicBaseWidge
 				$this->setMsg(self::MSG_GUIDANCE, $this->_('Data updated.'));		// データを更新しました
 			}
 			// システムパラメータを更新
-			$this->gEnv->loadSystemParams();
+			//$this->gEnv->loadSystemParams();
 			
 			// 値を再取得
-			$this->defaultLang		= $this->gEnv->getDefaultLanguage();
+			//$this->langId		= $this->gEnv->getDefaultLanguage();
 		} else if ($act == 'testmail'){		// テストメール送信のとき
-			$mail = $this->gEnv->getSiteEmail(true);
-			if (empty($mail)){
+			//$email = $this->gEnv->getSiteEmail(true);
+			$email = $this->db->getSiteDef($this->langId, M3_TB_FIELD_SITE_EMAIL);
+			if (empty($email)){
 				$this->setAppErrorMsg($this->_('Input email address.'));		// メールアドレスが設定されていません
 			} else {
-				$mailParam = array();
-				$mailParam['BODY']  = $this->_('URL   :') . ' ' . $this->gEnv->getRootUrl() . M3_NL;		// URL     :
-				$mailParam['BODY'] .= $this->_('Date  :') . ' ' . date("Y年m月d日 H時i分s秒") . M3_NL;		// 送信日時:
-				$mailParam['BODY'] .= $this->_('Sender:') . ' ' . $this->gEnv->getCurrentUserName() . M3_NL;	// 送信者  :
-				$ret = $this->gInstance->getMailManager()->sendFormMail(2/*手動送信*/, $this->gEnv->getCurrentWidgetId(), $mail, $mail, '', '', self::TEST_MAIL_FORM, $mailParam);
+				$emailParam = array();
+				$emailParam['BODY']  = $this->_('URL   :') . ' ' . $this->gEnv->getRootUrl() . M3_NL;		// URL     :
+				$emailParam['BODY'] .= $this->_('Date  :') . ' ' . date("Y年m月d日 H時i分s秒") . M3_NL;		// 送信日時:
+				$emailParam['BODY'] .= $this->_('Sender:') . ' ' . $this->gEnv->getCurrentUserName() . M3_NL;	// 送信者  :
+				$ret = $this->gInstance->getMailManager()->sendFormMail(2/*手動送信*/, $this->gEnv->getCurrentWidgetId(), $email, $email, '', '', self::TEST_MAIL_FORM, $emailParam);
 				if ($ret){
-					$this->setMsg(self::MSG_GUIDANCE, $this->_('Email sent. To:') . ' ' . $mail);// メールを送信しました。メールアドレス:
+					$this->setMsg(self::MSG_GUIDANCE, $this->_('Email sent. To:') . ' ' . $email);// メールを送信しました。メールアドレス:
 				} else {
-					$this->setMsg(self::MSG_APP_ERR, $this->_('Failed in sending email. To:') . ' ' . $mail);			// メール送信に失敗しました。メールアドレス:
+					$this->setMsg(self::MSG_APP_ERR, $this->_('Failed in sending email. To:') . ' ' . $email);			// メール送信に失敗しました。メールアドレス:
 				}
 			}
 		} else if ($act == 'upload'){		// 画像アップロードのとき
@@ -256,7 +261,10 @@ class admin_mainConfigsiteWidgetContainer extends admin_mainConfigbasicBaseWidge
 									}
 								}
 							}
-							if (!$ret){
+							if ($ret){
+								$msg = $this->_('Image changed.');			// 画像を変更しました
+								$this->setGuidanceMsg($msg);
+							} else {
 								$msg = $this->_('Failed in creating image.');			// 画像の作成に失敗しました
 								$this->setAppErrorMsg($msg);
 							}
@@ -269,30 +277,43 @@ class admin_mainConfigsiteWidgetContainer extends admin_mainConfigbasicBaseWidge
 					unlink($tmpFile);
 				}
 			} else {
-				$msg = sprintf($this->_('Uploded file not found. (detail: The file may be over maximum size to be allowed to upload. Size %d bytes.'), $this->gSystem->getMaxFileSizeForUpload());	// アップロードファイルが見つかりません(要因：アップロード可能なファイルのMaxサイズを超えている可能性があります。%dバイト)
+				$msg = sprintf($this->_('Uploded file not found. (detail: The file may be over maximum size to be allowed to upload. Size %s bytes.'), $this->gSystem->getMaxFileSizeForUpload());	// アップロードファイルが見つかりません(要因：アップロード可能なファイルのMaxサイズを超えている可能性があります。%dバイト)
 				$this->setAppErrorMsg($msg);
 			}
 		} else {		// 初期表示の場合
 
 		}
+		
+		// 一覧の表示タイプを設定
+		if ($this->isMultiLang){		// 多言語対応の場合
+			$this->tmpl->setAttribute('show_multilang', 'visibility', 'visible');
+			
+			// 言語選択メニュー作成
+			$this->createLangMenu();
+			$this->tmpl->setAttribute('select_lang', 'visibility', 'visible');
+		}
+		
 		// 画面にデータを埋め込む
-		$siteEmail = $this->gEnv->getSiteEmail(true);
-		$this->tmpl->addVar("_widget", "license_key", $this->db->getSiteDef($this->defaultLang, self::LICENSE_KEY));
-		$this->tmpl->addVar("_widget", "license_email", $this->db->getSiteDef($this->defaultLang, self::LICENSE_EMAIL));
-		$this->tmpl->addVar("_widget", "license_name", $this->db->getSiteDef($this->defaultLang, self::LICENSE_NAME));
-		$this->tmpl->addVar("_widget", "license_zipcode", $this->db->getSiteDef($this->defaultLang, self::LICENSE_ZIPCODE));
-		$this->tmpl->addVar("_widget", "license_address", $this->db->getSiteDef($this->defaultLang, self::LICENSE_ADDRESS));
-		$this->tmpl->addVar("_widget", "license_fax", $this->db->getSiteDef($this->defaultLang, self::LICENSE_FAX));
+		//$siteEmail = $this->gEnv->getSiteEmail(true);
+		$siteEmail = $this->db->getSiteDef($this->langId, M3_TB_FIELD_SITE_EMAIL);
+/*		$this->tmpl->addVar("_widget", "license_key", $this->db->getSiteDef($this->langId, self::LICENSE_KEY));
+		$this->tmpl->addVar("_widget", "license_email", $this->db->getSiteDef($this->langId, self::LICENSE_EMAIL));
+		$this->tmpl->addVar("_widget", "license_name", $this->db->getSiteDef($this->langId, self::LICENSE_NAME));
+		$this->tmpl->addVar("_widget", "license_zipcode", $this->db->getSiteDef($this->langId, self::LICENSE_ZIPCODE));
+		$this->tmpl->addVar("_widget", "license_address", $this->db->getSiteDef($this->langId, self::LICENSE_ADDRESS));
+		$this->tmpl->addVar("_widget", "license_fax", $this->db->getSiteDef($this->langId, self::LICENSE_FAX));
+		*/
 //		$this->tmpl->addVar("_widget", "site_name", $this->gEnv->getSiteName(true));		// サイト名
-		$this->tmpl->addVar("_widget", "site_name", $this->gSystem->getSiteDef(M3_TB_FIELD_SITE_NAME));		// サイト名
+		$this->tmpl->addVar("_widget", "site_name", $this->db->getSiteDef($this->langId, M3_TB_FIELD_SITE_NAME));		// サイト名
 		$this->tmpl->addVar("_widget", "site_email", $siteEmail);
-		$this->tmpl->addVar("_widget", "site_copyright", $this->gEnv->getSiteCopyRight(true));	// 著作権
+		//$this->tmpl->addVar("_widget", "site_copyright", $this->gEnv->getSiteCopyRight(true));	// 著作権
+		$this->tmpl->addVar("_widget", "site_copyright", $this->db->getSiteDef($this->langId, M3_TB_FIELD_SITE_COPYRIGHT));	// 著作権
 		
 		// SEO
-		$this->tmpl->addVar("_widget", "site_title", $this->db->getSiteDef($this->defaultLang, M3_TB_FIELD_SITE_TITLE));
-		$this->tmpl->addVar("_widget", "site_desc", $this->db->getSiteDef($this->defaultLang, M3_TB_FIELD_SITE_DESCRIPTION));
-		$this->tmpl->addVar("_widget", "site_keyword", $this->db->getSiteDef($this->defaultLang, M3_TB_FIELD_SITE_KEYWORDS));
-		$this->tmpl->addVar("_widget", "meta_others", $this->db->getSiteDef($this->defaultLang, self::SD_HEAD_OTHERS));		// ヘッダその他タグ
+		$this->tmpl->addVar("_widget", "site_title", $this->db->getSiteDef($this->langId, M3_TB_FIELD_SITE_TITLE));
+		$this->tmpl->addVar("_widget", "site_desc", $this->db->getSiteDef($this->langId, M3_TB_FIELD_SITE_DESCRIPTION));
+		$this->tmpl->addVar("_widget", "site_keyword", $this->db->getSiteDef($this->langId, M3_TB_FIELD_SITE_KEYWORDS));
+		$this->tmpl->addVar("_widget", "meta_others", $this->db->getSiteDef($this->langId, self::SD_HEAD_OTHERS));		// ヘッダその他タグ
 		
 		// サイトロゴ
 		$siteLogoUrl = $this->gEnv->getResourceUrl() . '/etc/site/thumb/' . $siteLogoFiles[0] . '?' . date('YmdHis');		// サイトロゴファイル名
@@ -320,5 +341,36 @@ class admin_mainConfigsiteWidgetContainer extends admin_mainConfigbasicBaseWidge
 		$localeText['label_update'] = $this->_('Update');// 更新
 		$this->setLocaleText($localeText);
 	}
+	/**
+	 * 言語選択メニューを作成
+	 *
+	 * @return 			なし
+	 */
+	function createLangMenu()
+	{
+		$ret = $this->db->getAvailableLang($rows);
+		if ($ret){
+			for ($i = 0; $i < count($rows); $i++){
+				$langRow = $rows[$i];
+
+				$selected = '';
+				if ($langRow['ln_id'] == $this->langId) $selected = 'selected';
+
+				if ($this->gEnv->getCurrentLanguage() == 'ja'){		// 日本語表示の場合
+					$name = $this->convertToDispString($langRow['ln_name']);
+				} else {
+					$name = $this->convertToDispString($langRow['ln_name_en']);
+				}
+
+				$row = array(
+					'value'    => $this->convertToDispString($langRow['ln_id']),			// 言語ID
+					'name'     => $name,			// 言語名
+					'selected' => $selected														// 選択中かどうか
+				);
+				$this->tmpl->addVars('lang_list', $row);
+				$this->tmpl->parseTemplate('lang_list', 'a');
+			}
+		}
+	}
 }
 ?>
