@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainMenuidWidgetContainer.php 2706 2009-12-18 06:41:53Z fishbone $
+ * @version    SVN: $Id: admin_mainMenuidWidgetContainer.php 5310 2012-10-25 06:35:11Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_mainMasterBaseWidgetContainer.php');
@@ -112,7 +112,7 @@ class admin_mainMenuidWidgetContainer extends admin_mainMasterBaseWidgetContaine
 			}
 		}
 		
-		$this->db->getMenuIdList(array($this, 'itemLoop'));
+		$this->db->getMenuIdList(array($this, 'itemLoop'), true/*すべてのメニューIDを取得*/);
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
 	}
 	/**
