@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: static_contentWidgetContainer.php 4674 2012-02-12 12:40:15Z fishbone $
+ * @version    SVN: $Id: static_contentWidgetContainer.php 4690 2012-02-16 15:37:54Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -87,7 +87,7 @@ class static_contentWidgetContainer extends BaseWidgetContainer
 		if (!empty($targetObj)){		// 定義データが取得できたとき
 			$name = $targetObj->name;// 定義名
 			$contentId	= $targetObj->contentId;		// コンテンツID
-			$hideInLogin = $targetObj->hideInLogin;		// ログイン中は非表示にする
+//			$hideInLogin = $targetObj->hideInLogin;		// ログイン中は非表示にする
 			
 			// コンテンツを取得
 			$ret = $this->db->getContentByContentId(self::CONTENT_TYPE, $contentId, $this->langId, $now, $row);
@@ -106,7 +106,7 @@ class static_contentWidgetContainer extends BaseWidgetContainer
 				if ($this->gEnv->isCurrentUserLogined() || !$row['cn_user_limited']) $showWidget = true;
 				
 				// ログイン中は非表示に設定されているときは非表示にする(非システム運用者の場合)
-				if (!$this->isSystemManageUser && !empty($hideInLogin) && $this->gEnv->isCurrentUserLogined()) $showWidget = false;
+//				if (!$this->isSystemManageUser && !empty($hideInLogin) && $this->gEnv->isCurrentUserLogined()) $showWidget = false;
 
 				$buttonType = 1;			// 編集ボタンタイプ(編集)
 				$contentId = $row['cn_id'];
